# -*- coding: utf-8 -*-
#Locations of remote files and local directory for cdf files
#You can change data_dir to a directory of your choice
data_dir='C:\\Datapy\\'
themis_remote='http://themis.ssl.berkeley.edu/data/themis'
omni_remote='https://cdaweb.gsfc.nasa.gov/istp_public/data/omni'
